############################################################################
#
# Gulf research problem
# as described in
#   M.M.  Ali,  C.  Khompatraporn  and  Z.B.  Zabinsky,   "A numerical
#   evaluation of several stochastic algorithms on selected continuous
#   global optimization test problems", Journal of Global Optimization
#   (2005) 31:635-672
#
# Coded for AMPL by: aivaz@dps.uminho.pt
# Minho University, Portugal
# 14 September 2005
############################################################################

# parameters
param n := 99;
param u {i in 1..n} := 25+(-50*log(0.01*i))^(1/1.5);

# variables
var x{1..3};

# objective function, minimization problem
minimize fx:
    (sum {i in 1..n} (exp(-(u[i]-x[2])^x[3]/x[1])-0.01*i))^2;

subject to bound1:
    0.1 <= x[1] <= 100;
    
subject to bound2:
    0 <= x[2] <= 25.6;
    
subject to bound3:
    0 <= x[3] <= 5;

include solver.mod;

display fx;
display x;

printf "Global minimizer at (50,25,1.5) with fx=0\n";
