############################################################################
#
# Least Median Squares problem
# as described in
#   M. Mongeau, H. Karsenty, V. Rouge, J.-B. Hiriat-Urruty, "Comparison of
#   public-domain software for black box global optimization", Optimization
#   Methods and Software, 13(3), pp. 203-226, 2000
#
# Coded for AMPL by: aivaz@dps.uminho.pt
# Minho University, Portugal
# 29 September 2005
############################################################################

# Include stats.dll as external dynamic library (ampl -i stats.dll)
function median;

# parameters
param p := 1;
param n := 24;
param x{1..n,1..p};
param y{1..n};


# variables
var theta{1..p};
var b;
var r{i in 1..n} = y[i]-sum {j in 1..p} (x[i,j]*theta[j]) - b;


# objective function, minimization problem
minimize fx:
    median({i in 1..n} r[i]^2);

subject to bounds {i in 1..p}:
    0 <= theta[i] <= 1;

subject to bbound:
    -10 <= b <= 10;

data;

param x: 1 :=
1   50
2   51
3   52
4   53
5   54
6   55
7   56
8   57
9   58
10  59
11  60
12  61
13  62
14  63
15  64
16  65
17  66
18  67
19  68
20  69
21  70
22  71
23  72
24  73; 

param y :=
1   0.44
2   0.47
3   0.47
4   0.59
5   0.66
6   0.73
7   0.81
8   0.88
9   1.06
10  1.20
11  1.35
12  1.49
13  1.61
14  2.12
15  11.90
16  12.40
17  14.20
18  15.90
19  18.20
20  21.20
21  4.30
22  2.40
23  2.70
24  2.90;

include solver.mod;

display fx;
display theta;
display b;
