############################################################################
#
# Least Median Squares problem
# as described in
#   M. Mongeau, H. Karsenty, V. Rouge, J.-B. Hiriat-Urruty, "Comparison of
#   public-domain software for black box global optimization", Optimization
#   Methods and Software, 13(3), pp. 203-226, 2000
#
# Coded for AMPL by: aivaz@dps.uminho.pt
# Minho University, Portugal
# 29 September 2005
############################################################################

# Include stats.dll as external dynamic library (ampl -i stats.dll)
function median;

# parameters
param p := 3;
param n := 21;
param x{1..n,1..p};
param y{1..n};


# variables
var theta{1..p};
var b;
var r{i in 1..n} = y[i]-sum {j in 1..p} (x[i,j]*theta[j]) - b;


# objective function, minimization problem
minimize fx:
    median({i in 1..n} r[i]^2);

subject to bounds {i in 1..p}:
    -2 <= theta[i] <= 2;

subject to bbound:
    -40 <= b <= 4;

data;

param x: 1 2 3 :=
1   80  27  89
2   80  27  88
3   75  25  90
4   62  24  87
5   62  22  87
6   62  23  87
7   62  24  93
8   62  24  93
9   58  23  87
10  58  18  80
11  58  18  89
12  58  17  88
13  58  18  82
14  58  19  93
15  50  18  89
16  50  18  86
17  50  19  72
18  50  19  79
19  50  20  80
20  56  20  82
21  70  20  91;

param y :=
1   42
2   37
3   37
4   28
5   18
6   18
7   19
8   20
9   15
10  14
11  14
12  13
13  11
14  12
15  8
16  7
17  8
18  8
19  9
20  15
21  15;

include solver.mod;

display fx;
display theta;
display b;
