############################################################################
#
# Multidimensional Scaling problem
# as described in
#   M. Mongeau, H. Karsenty, V. Rouge, J.-B. Hiriat-Urruty, "Comparison of
#   public-domain software for black box global optimization", Optimization
#   Methods and Software, 13(3), pp. 203-226, 2000
#
# Coded for AMPL by: aivaz@dps.uminho.pt
# Minho University, Portugal
# 29 September 2005
############################################################################

# parameters
param n := 10;
#param omega{1..n,1..n};
param delta{1..n,1..n};


# variables
var x{1..2,1..n};
var v{i in 1..n, j in 1..i-1} = sqrt(sum {k in 1..2} (x[k,i]-x[k,j])^2);

# objective function, minimization problem
minimize fx:
#    sum {i in 1..n} (sum {j in 1..i-1} (omega[i,j]*(delta[i,j]-v[i,j])^2));
    sum {i in 1..n} (sum {j in 1..i-1} (delta[i,j]-v[i,j])^2);

subject to bounds {i in 1..n, k in 1..2}:
    -5 <= x[k,i] <= 5;


data;

param delta: 1 2 3 4 5 6 7 8 9 10:=
1   .       .       .       .       .       .       .       .       .       .
2   0.49    .       .       .       .       .       .       .       .       .
3   1.74    1.47    .       .       .       .       .       .       .       .
4   2.26    2.08    2.67    .       .       .       .       .       .       .
5   2.14    1.84    0.84    2.67    .       .       .       .       .       .
6   1.85    1.39    1.32    1.92    1.39    .       .       .       .       .
7   1.62    1.43    1.70    1.74    1.39    1.48    .       .       .       .
8   0.79    0.82    1.59    1.96    2.04    1.78    1.66    .       .       .
9   1.87    1.69    1.66    1.76    2.01    1.47    1.84    1.68    .       .
10  1.85    1.50    1.67    2.28    1.38    1.11    1.06    2.11    2.97    .;


include solver.mod;

display fx;
display x;
