############################################################################
#
# Multidimensional Scaling problem
# as described in
#   M. Mongeau, H. Karsenty, V. Rouge, J.-B. Hiriat-Urruty, "Comparison of
#   public-domain software for black box global optimization", Optimization
#   Methods and Software, 13(3), pp. 203-226, 2000
#
# Coded for AMPL by: aivaz@dps.uminho.pt
# Minho University, Portugal
# 29 September 2005
############################################################################

# parameters
param n := 10;
#param omega{1..n,1..n};
param delta{1..n,1..n};


# variables
var x{1..2,1..n};
var v{i in 1..n, j in 1..i-1} = sqrt(sum {k in 1..2} (x[k,i]-x[k,j])^2);

# objective function, minimization problem
minimize fx:
#    sum {i in 1..n} (sum {j in 1..i-1} (omega[i,j]*(delta[i,j]-v[i,j])^2));
    sum {i in 1..n} (sum {j in 1..i-1} (delta[i,j]-v[i,j])^2);

subject to bounds {i in 1..n, k in 1..2}:
    -5 <= x[k,i] <= 5;


data;

param delta: 1 2 3 4 5 6 7 8 9 10:=
1   .       .       .       .       .       .       .       .       .       .
2   1.27    .       .       .       .       .       .       .       .       .
3   1.69    1.43    .       .       .       .       .       .       .       .
4   2.04    2.35    2.43    .       .       .       .       .       .       .
5   3.09    3.18    3.26    2.85    .       .       .       .       .       .
6   3.20    3.22    3.27    2.88    1.55    .       .       .       .       .
7   2.86    2.56    2.58    2.59    3.12    3.06    .       .       .       .
8   3.17    3.18    3.18    3.12    1.31    1.64    3.00    .       .       .
9   3.21    3.18    3.18    3.17    1.70    1.36    2.95    1.32    .       .
10  2.38    2.31    2.42    1.94    2.85    2.81    2.56    2.91    2.97    .;


include solver.mod;

display fx;
display x;
